class UsefulException(Exception):
  pass

class NotMatched(UsefulException):
  pass

class InvalidCommand(UsefulException):
  def __init__(self, klass, exception, *args, **kwargs):
    self.klass = klass
    self.exception = exception
    super(InvalidCommand, self).__init__(*args, **kwargs)

class NeedsRoot(UsefulException):
  pass

class CommandError(UsefulException):
  pass